#!/usr/bin/env python
# coding: utf-8

# In[ ]:


from setuptools import find_packages, setup
setup(
    name='Transsa5',
    version='1.0.1',
    packages=find_packages(),
    py_modules=['Transsa5']

)


